@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# const.py - A set of structures and constants used to implement the Ethernet/IP protocol
-#
-# Copyright (c) 2019 Ian Ottoway <ian@ottoway.dev>
+# Copyright (c) 2020 Ian Ottoway <ian@ottoway.dev>
 # Copyright (c) 2014 Agostino Ruscito <ruscito@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -24,11 +22,13 @@
 # SOFTWARE.
 #
 
+__all__ = ['CIPDriver', 'with_forward_open', 'parse_connection_path', ]
+
 import logging
 import socket
 from functools import wraps
 from os import urandom
-from typing import Union, Optional
+from typing import Union, Optional, List
 
 from .exceptions import DataError, CommError, RequestError
 from .tag import Tag
@@ -40,9 +40,6 @@ from .packets import REQUEST_MAP, RequestPacket, DataFormatType
 from .socket_ import Socket
 
 
-# re_bit = re.compile(r'(?P<base>^.*)\.(?P<bit>([0-2][0-9])|(3[01])|[0-9])$')
-
-
 def with_forward_open(func):
     """Decorator to ensure a forward open request has been completed with the plc"""
 
@@ -69,11 +66,12 @@ def with_forward_open(func):
 
 class CIPDriver:
     """
-    An Ethernet/IP Client library for reading and writing tags in ControlLogix and CompactLogix PLCs.
+    A base CIP driver for the SLCDriver and LogixDriver classes.  Implements common CIP services like
+    (un)registering sessions, forward open/close, generic messaging, etc.
     """
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
 
-    def __init__(self, path: str, *args,  large_packets: bool = True, **kwargs):
+    def __init__(self, path: str, *args, large_packets: bool = True, **kwargs):
         """
         :param path: CIP path to intended target
 
@@ -310,16 +308,16 @@ class CIPDriver:
         forward_open_msg = [
             PRIORITY,
             TIMEOUT_TICKS,
-            b'\x00\x00\x00\x00',
+            b'\x00\x00\x00\x00',  # O->T produced connection ID, not needed for us so leave blank
             self._cfg['cid'],
             self._cfg['csn'],
             self._cfg['vid'],
             self._cfg['vsn'],
             TIMEOUT_MULTIPLIER,
-            b'\x00\x00\x00',
-            b'\x01\x40\x20\x00',
+            b'\x00\x00\x00',  # reserved
+            b'\x01\x40\x20\x00',  # O->T RPI in microseconds, RPIs are not important for us so fixed value is fine
             net_params,
-            b'\x01\x40\x20\x00',
+            b'\x01\x40\x20\x00',  # T->O RPI
             net_params,
             TRANSPORT_CLASS,
         ]
@@ -337,7 +335,8 @@ class CIPDriver:
         if response:
             self._target_cid = response.value[:4]
             self._target_is_connected = True
-            self.__log.info(f"{'Extended ' if self._cfg['extended forward open'] else ''}Forward Open succeeded. Target CID={self._target_cid}")
+            self.__log.info(
+                f"{'Extended ' if self._cfg['extended forward open'] else ''}Forward Open succeeded. Target CID={self._target_cid}")
             return True
         self.__log.warning(f"forward_open failed - {response.error}")
         return False
