@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# const.py - A set of structures and constants used to implement the Ethernet/IP protocol
-#
-# Copyright (c) 2019 Ian Ottoway <ian@ottoway.dev>
+# Copyright (c) 2020 Ian Ottoway <ian@ottoway.dev>
 # Copyright (c) 2014 Agostino Ruscito <ruscito@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -24,11 +22,13 @@
 # SOFTWARE.
 #
 
+__all__ = ['LogixDriver', ]
+
 import datetime
 import itertools
 import logging
 import time
-from typing import Union, List, Tuple, Optional
+from typing import List, Tuple, Optional, Union
 
 from .exceptions import DataError, CommError, RequestError
 from .tag import Tag
@@ -40,18 +40,18 @@ from .const import (TagService, EXTENDED_SYMBOL, CLASS_TYPE, INSTANCE_TYPE, Clas
                     TEMPLATE_MEMBER_INFO_LEN, EXTERNAL_ACCESS, DataTypeSize, MIN_VER_EXTERNAL_ACCESS)
 from .packets import request_path
 
-AtomicType = Union[int, float, bool, str]
-TagType = Union[AtomicType, List[AtomicType]]
-ReturnType = Union[Tag, List[Tag]]
+AtomicValueType = Union[int, float, bool, str]
+TagValueType = Union[AtomicValueType, List[AtomicValueType]]
+ReadWriteReturnType = Union[Tag, List[Tag]]
 
 
 class LogixDriver(CIPDriver):
     """
-    An Ethernet/IP Client library for reading and writing tags in ControlLogix and CompactLogix PLCs.
+    An Ethernet/IP Client driver for reading and writing tags in ControlLogix and CompactLogix PLCs.
     """
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
 
-    def __init__(self, path: str, *args,  large_packets: bool = True, micro800: bool = False,
+    def __init__(self, path: str, *args,  micro800: bool = False,
                  init_info: bool = True, init_tags: bool = True, init_program_tags: bool = False, **kwargs):
         """
         :param path: CIP path to intended target
@@ -68,15 +68,6 @@ class LogixDriver(CIPDriver):
                 CIP path automatically.  The ``enet`` / ``backplane`` (or ``bp``) segments are symbols for the CIP routing
                 port numbers and will be replaced with the correct value.
 
-        :param large_packets: if True (default), the *Extended Forward Open* service will be used
-
-            .. note::
-
-                *Extended Forward Open* allows the used of 4KBs of service data in each request.
-                The standard *Forward Open* is limited to 500 bytes.  Not all hardware supports the large packet size,
-                like ENET or ENBT modules or ControlLogix version 19 or lower.  **This argument is no longer required
-                as of 0.5.1, since it will automatically try a standard Forward Open if the extended one fails**
-
         :param init_info:  if True (default), initializes controller info (name, revision, etc) on connect
 
             .. note::
@@ -98,7 +89,7 @@ class LogixDriver(CIPDriver):
 
         """
 
-        super().__init__(path, *args, large_packets=large_packets, **kwargs)
+        super().__init__(path, *args, **kwargs)
         self._cache = None
         self._data_types = {}
         self._tags = {}
@@ -650,7 +641,7 @@ class LogixDriver(CIPDriver):
         return self._cache['id:udt'][instance_id]
 
     @with_forward_open
-    def read(self, *tags: str) -> ReturnType:
+    def read(self, *tags: str) -> ReadWriteReturnType:
         """
         Read the value of tag(s).  Automatically will split tags into multiple requests by tracking the request and
         response size.  Will use the multi-service request to group many tags into a single packet and also will automatically
@@ -758,7 +749,7 @@ class LogixDriver(CIPDriver):
         return None
 
     @with_forward_open
-    def write(self, *tags_values: Tuple[str, TagType]) -> ReturnType:
+    def write(self, *tags_values: Tuple[str, TagValueType]) -> ReadWriteReturnType:
         """
         Write to tag(s). Automatically will split tags into multiple requests by tracking the request and
         response size.  Will use the multi-service request to group many tags into a single packet and also will automatically
@@ -1124,7 +1115,7 @@ def writable_value(parsed_tag):
 
         if elements > 1:
             if len(value) < elements:
-                raise RequestError('Insufficient data for requested elements')
+                raise RequestError(f'Insufficient data for requested elements, expected {elements} and got {len(value)}')
             if len(value) > elements:
                 value = value[:elements]
 
@@ -1138,7 +1129,7 @@ def writable_value(parsed_tag):
             else:
                 return pack_func(value)
     except Exception as err:
-        raise RequestError('Unable to create a writable value', err)
+        raise RequestError('Unable to create a writable value') from err
 
 
 def _strip_array(tag):
