@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# const.py - A set of structures and constants used to implement the Ethernet/IP protocol
-#
-# Copyright (c) 2019 Ian Ottoway <ian@ottoway.dev>
+# Copyright (c) 2020 Ian Ottoway <ian@ottoway.dev>
 # Copyright (c) 2014 Agostino Ruscito <ruscito@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -56,6 +54,13 @@ SEC_TO_US = 1_000_000  # seconds to microseconds
 TEMPLATE_MEMBER_INFO_LEN = 8  # 2B bit/array len, 2B datatype, 4B offset
 STRUCTURE_READ_REPLY = b'\xa0\x02'
 
+SLC_CMD_CODE = b'\x0F'
+SLC_CMD_REPLY_CODE = b'\x4F'
+SLC_FNC_READ = b'\xa2'  # protected typed logical read w/ 3 address fields
+SLC_FNC_WRITE = b'\xaa'  # protected typed logical write w/ 3 address fields
+SLC_REPLY_START = 61
+PCCC_PATH = b'\x67\x24\x01'
+
 ELEMENT_TYPE = {
     "8-bit": b'\x28',
     "16-bit": b'\x29\x00',
@@ -503,6 +508,33 @@ PCCC_ERROR_CODE = {
 }
 
 
+# UNPACK_PCCC_DATA_FUNCTION = {
+#     'N': unpack_int,
+#     'B': unpack_int,
+#     'T': unpack_int,
+#     'C': unpack_int,
+#     'S': unpack_int,
+#     'F': unpack_real,
+#     'A': unpack_sint,
+#     'R': unpack_dint,
+#     'O': unpack_int,
+#     'I': unpack_int
+# }
+#
+# PACK_PCCC_DATA_FUNCTION = {
+#     'N': pack_int,
+#     'B': pack_int,
+#     'T': pack_int,
+#     'C': pack_int,
+#     'S': pack_int,
+#     'F': pack_real,
+#     'A': pack_sint,
+#     'R': pack_dint,
+#     'O': pack_int,
+#     'I': pack_int
+# }
+
+
 #  Taken from PyLogix
 # List originally came from Wireshark /epan/dissectors/packet-cip.c
 PRODUCT_TYPES = {
