@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# const.py - A set of structures and constants used to implement the Ethernet/IP protocol
-#
-# Copyright (c) 2019 Ian Ottoway <ian@ottoway.dev>
+# Copyright (c) 2020 Ian Ottoway <ian@ottoway.dev>
 # Copyright (c) 2014 Agostino Ruscito <ruscito@gmail.com>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -41,7 +39,7 @@ from ..const import (EncapsulationCommand, INSUFFICIENT_PACKETS, DataItem, Addre
 
 
 class RequestPacket(Packet):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _message_type = None
     _address_type = None
     _timeout = b'\x0a\x00'  # 10
@@ -150,7 +148,7 @@ class RequestPacket(Packet):
 
 
 class SendUnitDataRequestPacket(RequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _message_type = DataItem.connected
     _address_type = AddressItem.connection
     _response_class = SendUnitDataResponsePacket
@@ -162,7 +160,7 @@ class SendUnitDataRequestPacket(RequestPacket):
 
 
 class ReadTagServiceRequestPacket(SendUnitDataRequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     type_ = 'read'
     _response_class = ReadTagServiceResponsePacket
 
@@ -203,7 +201,7 @@ class ReadTagServiceRequestPacket(SendUnitDataRequestPacket):
 
 
 class ReadTagFragmentedServiceRequestPacket(SendUnitDataRequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     type_ = 'read'
     _response_class = ReadTagFragmentedServiceResponsePacket
 
@@ -259,7 +257,7 @@ class ReadTagFragmentedServiceRequestPacket(SendUnitDataRequestPacket):
 
 
 class WriteTagServiceRequestPacket(SendUnitDataRequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     type_ = 'write'
     _response_class = WriteTagServiceResponsePacket
 
@@ -297,7 +295,7 @@ class WriteTagServiceRequestPacket(SendUnitDataRequestPacket):
 
 
 class WriteTagFragmentedServiceRequestPacket(SendUnitDataRequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     type_ = 'write'
     _response_class = WriteTagFragmentedServiceResponsePacket
 
@@ -376,7 +374,7 @@ class WriteTagFragmentedServiceRequestPacket(SendUnitDataRequestPacket):
 
 
 class MultiServiceRequestPacket(SendUnitDataRequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     type_ = 'multi'
     _response_class = MultiServiceResponsePacket
 
@@ -512,7 +510,7 @@ def _make_write_data_bit(tag_info, value, request_path):
 
 
 class SendRRDataRequestPacket(RequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _message_type = DataItem.unconnected
     _address_type = AddressItem.uccm
     _encap_command = EncapsulationCommand.send_rr_data
@@ -523,7 +521,7 @@ class SendRRDataRequestPacket(RequestPacket):
 
 
 class RegisterSessionRequestPacket(RequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _encap_command = EncapsulationCommand.register_session
     _response_class = RegisterSessionResponsePacket
 
@@ -532,7 +530,7 @@ class RegisterSessionRequestPacket(RequestPacket):
 
 
 class UnRegisterSessionRequestPacket(RequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _encap_command = EncapsulationCommand.unregister_session
     _response_class = UnRegisterSessionResponsePacket
 
@@ -544,7 +542,7 @@ class UnRegisterSessionRequestPacket(RequestPacket):
 
 
 class ListIdentityRequestPacket(RequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _encap_command = EncapsulationCommand.list_identity
     _response_class = ListIdentityResponsePacket
 
@@ -629,7 +627,7 @@ def _encode_tag_index(index):
 
 
 class GenericConnectedRequestPacket(SendUnitDataRequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _response_class = GenericConnectedResponsePacket
 
     def __init__(self, plc):
@@ -660,7 +658,7 @@ class GenericConnectedRequestPacket(SendUnitDataRequestPacket):
 
 
 class GenericUnconnectedRequestPacket(SendRRDataRequestPacket):
-    __log = logging.getLogger(__qualname__)
+    __log = logging.getLogger(f'{__module__}.{__qualname__}')
     _response_class = GenericUnconnectedResponsePacket
 
     def __init__(self, plc):
